@@ -5,6 +5,7 @@ import annofabcli.annotation.change_annotation_attributes
 import annofabcli.annotation.delete_annotation
 import annofabcli.annotation.dump_annotation
 import annofabcli.annotation.import_annotation
+import annofabcli.annotation.list_annotation
 import annofabcli.annotation.list_annotation_count
 import annofabcli.annotation.restore_anotation
 import annofabcli.common.cli
@@ -19,6 +20,7 @@ def parse_args(parser: argparse.ArgumentParser):
     annofabcli.annotation.delete_annotation.add_parser(subparsers)
     annofabcli.annotation.dump_annotation.add_parser(subparsers)
     annofabcli.annotation.import_annotation.add_parser(subparsers)
+    annofabcli.annotation.list_annotation.add_parser(subparsers)
     annofabcli.annotation.list_annotation_count.add_parser(subparsers)
     annofabcli.annotation.restore_anotation.add_parser(subparsers)
 
