@@ -1,11 +1,12 @@
 import asyncio
 import logging.config
+import warnings
 from functools import partial
 from typing import Optional
 
 import annofabapi
 import requests
-from annofabapi.models import JobType
+from annofabapi.models import ProjectJobType
 
 from annofabcli.common.dataclasses import WaitOptions
 from annofabcli.common.exceptions import DownloadingFileNotFoundError, UpdatedFileForDownloadingError
@@ -13,17 +14,24 @@ from annofabcli.common.exceptions import DownloadingFileNotFoundError, UpdatedFi
 logger = logging.getLogger(__name__)
 
 DOWNLOADING_FILETYPE_DICT = {
-    JobType.GEN_TASKS_LIST: "タスク全件ファイル",
-    JobType.GEN_INPUTS_LIST: "入力データ全件ファイル",
-    JobType.GEN_ANNOTATION: "アノテーションzip",
+    ProjectJobType.GEN_TASKS_LIST: "タスク全件ファイル",
+    ProjectJobType.GEN_INPUTS_LIST: "入力データ全件ファイル",
+    ProjectJobType.GEN_ANNOTATION: "アノテーションzip",
 }
 
 DEFAULT_WAIT_OPTIONS = WaitOptions(interval=60, max_tries=360)
 
 
+def _get_annofab_error_message(http_error: requests.HTTPError) -> Optional[str]:
+    obj = http_error.response.json()
+    errors = obj.get("errors")
+    if errors is None:
+        return None
+    return errors[0].get("message")
+
+
 class DownloadingFile:
-    """
-    """
+    """"""
 
     def __init__(self, service: annofabapi.Resource):
         self.service = service
@@ -35,7 +43,7 @@ class DownloadingFile:
     def _wait_for_completion(
         self,
         project_id: str,
-        job_type: JobType,
+        job_type: ProjectJobType,
         wait_options: Optional[WaitOptions] = None,
         job_id: Optional[str] = None,
     ):
@@ -68,16 +76,16 @@ class DownloadingFile:
         logger.debug(f"アノテーションzipをダウンロードします。path={dest_path}")
         if is_latest:
             self.wait_until_updated_annotation_zip(project_id, wait_options)
-            self.service.wrapper.download_annotation_archive(project_id, dest_path, v2=True)
+            self.service.wrapper.download_annotation_archive(project_id, dest_path)
 
         else:
             try:
-                self.service.wrapper.download_annotation_archive(project_id, dest_path, v2=True)
+                self.service.wrapper.download_annotation_archive(project_id, dest_path)
             except requests.HTTPError as e:
                 if e.response.status_code == requests.codes.not_found:
                     logger.info(f"アノテーションzipが存在しなかったので、アノテーションzipファイルの更新処理を実行します。")
                     self.wait_until_updated_annotation_zip(project_id, wait_options)
-                    self.service.wrapper.download_annotation_archive(project_id, dest_path, v2=True)
+                    self.service.wrapper.download_annotation_archive(project_id, dest_path)
                 else:
                     raise e
 
@@ -89,11 +97,14 @@ class DownloadingFile:
         except requests.HTTPError as e:
             # すでにジョブが進行中の場合は、無視する
             if e.response.status_code == requests.codes.conflict:
-                logger.info(f"アノテーションzipの更新処理が既に実行されています。")
+                logger.warning(f"別のバックグラウンドジョブが既に実行されているので、更新処理を無視します。")
+                logger.warning(f"{_get_annofab_error_message(e)}")
             else:
                 raise e
 
-        self._wait_for_completion(project_id, job_type=JobType.GEN_ANNOTATION, wait_options=wait_options, job_id=job_id)
+        self._wait_for_completion(
+            project_id, job_type=ProjectJobType.GEN_ANNOTATION, wait_options=wait_options, job_id=job_id
+        )
 
     async def download_input_data_json_with_async(
         self, project_id: str, dest_path: str, is_latest: bool = False, wait_options: Optional[WaitOptions] = None
@@ -130,12 +141,13 @@ class DownloadingFile:
         except requests.HTTPError as e:
             # すでにジョブが進行中の場合は、無視する
             if e.response.status_code == requests.codes.conflict:
-                logger.info(f"入力データ全件ファイルの更新処理が既に実行されています。")
+                logger.warning(f"別のバックグラウンドジョブが既に実行されているので、更新処理を無視します。")
+                logger.warning(f"{_get_annofab_error_message(e)}")
             else:
                 raise e
 
         self._wait_for_completion(
-            project_id, job_type=JobType.GEN_INPUTS_LIST, wait_options=wait_options, job_id=job_id
+            project_id, job_type=ProjectJobType.GEN_INPUTS_LIST, wait_options=wait_options, job_id=job_id
         )
 
     async def download_task_json_with_async(
@@ -173,11 +185,14 @@ class DownloadingFile:
         except requests.HTTPError as e:
             # すでにジョブが進行中の場合は、無視する
             if e.response.status_code == requests.codes.conflict:
-                logger.info(f"タスク全件ファイルの更新処理が既に実行されています。")
+                logger.warning(f"別のバックグラウンドジョブが既に実行されているので、更新処理を無視します。")
+                logger.warning(f"{_get_annofab_error_message(e)}")
             else:
                 raise e
 
-        self._wait_for_completion(project_id, job_type=JobType.GEN_TASKS_LIST, wait_options=wait_options, job_id=job_id)
+        self._wait_for_completion(
+            project_id, job_type=ProjectJobType.GEN_TASKS_LIST, wait_options=wait_options, job_id=job_id
+        )
 
     async def download_task_history_json_with_async(self, project_id: str, dest_path: str):
         """
@@ -208,6 +223,40 @@ class DownloadingFile:
                 raise DownloadingFileNotFoundError("タスク履歴全件ファイルが存在しません。") from e
             raise e
 
+    def download_task_history_event_json(self, project_id: str, dest_path: str):
+        """
+        タスク履歴イベント全件ファイルをダウンロードする。
+
+        .. deprecated:: 0.21.1
+
+        Args:
+            project_id:
+            dest_path:
+
+        Raises:
+            DownloadingFileNotFoundError:
+        """
+        try:
+            logger.debug(f"タスク履歴イベント全件ファイルをダウンロードします。path={dest_path}")
+            self.service.wrapper.download_project_task_history_events_url(project_id, dest_path)
+        except requests.HTTPError as e:
+            if e.response.status_code == requests.codes.not_found:
+                logger.info(f"タスク履歴イベント全件ファイルが存在しません。")
+                raise DownloadingFileNotFoundError("タスク履歴イベント全件ファイルが存在しません。") from e
+            raise e
+
+    async def download_task_history_event_json_with_async(self, project_id: str, dest_path: str):
+        """
+        非同期で検査コメント全件ファイルをダウンロードする。
+
+        .. deprecated:: 0.21.1
+
+        Raises:
+            DownloadingFileNotFoundError:
+        """
+        warnings.warn("deprecated", DeprecationWarning)
+        return self.download_task_history_event_json(project_id, dest_path=dest_path)
+
     async def download_inspection_json_with_async(self, project_id: str, dest_path: str):
         """
         非同期で検査コメント全件ファイルをダウンロードする。
