@@ -1,7 +1,3 @@
-"""
-annofabapiのfacadeクラス
-"""
-
 import enum
 from typing import Any, Dict, List, Optional
 
@@ -12,12 +8,15 @@ from annofabapi.models import (
     InputData,
     Inspection,
     OrganizationMember,
+    ProjectMember,
+    SingleAnnotation,
     Task,
     TaskHistory,
     TaskPhase,
 )
 from annofabapi.utils import get_number_of_rejections
 
+from annofabcli.common.facade import convert_annotation_specs_labels_v2_to_v1
 from annofabcli.common.utils import isoduration_to_hour
 
 
@@ -33,14 +32,18 @@ class AddProps:
 
     #: 組織メンバ一覧のキャッシュ
     _organization_members: Optional[List[OrganizationMember]] = None
+    _project_member_list: Optional[List[ProjectMember]] = None
 
     def __init__(self, service: annofabapi.Resource, project_id: str):
         self.service = service
         self.project_id = project_id
         self.organization_name = self._get_organization_name_from_project_id(project_id)
 
-        annotation_specs, _ = self.service.api.get_annotation_specs(project_id)
-        self.specs_labels: List[Dict[str, Any]] = annotation_specs["labels"]
+        # [REMOVE_V2_PARAM]
+        annotation_specs, _ = self.service.api.get_annotation_specs(project_id, query_params={"v": "2"})
+        self.specs_labels: List[Dict[str, Any]] = convert_annotation_specs_labels_v2_to_v1(
+            labels_v2=annotation_specs["labels"], additionals_v2=annotation_specs["additionals"]
+        )
         self.specs_inspection_phrases: List[Dict[str, Any]] = annotation_specs["inspection_phrases"]
 
     @staticmethod
@@ -67,7 +70,7 @@ class AddProps:
 
         account_id = target["account_id"]
         if account_id is not None:
-            member = self.get_organization_member_from_account_id(account_id)
+            member = self.get_project_member_from_account_id(account_id)
             if member is not None:
                 user_id = member["user_id"]
                 username = member["username"]
@@ -76,6 +79,17 @@ class AddProps:
         target["username"] = username
         return target
 
+    def get_project_member_from_account_id(self, account_id: str) -> Optional[ProjectMember]:
+        if self._project_member_list is None:
+            project_member_list = self.service.wrapper.get_all_project_members(
+                self.project_id, query_params={"include_inactive_member": True}
+            )
+            self._project_member_list = project_member_list
+        else:
+            project_member_list = self._project_member_list
+
+        return more_itertools.first_true(project_member_list, pred=lambda e: e["account_id"] == account_id)
+
     def get_organization_member_from_account_id(self, account_id: str) -> Optional[OrganizationMember]:
         """
         account_idから組織メンバを取得する.
@@ -174,6 +188,20 @@ class AddProps:
         """
         return self._add_user_info(annotation_specs_history)
 
+    def add_properties_to_instruction(self, instruction_history: AnnotationSpecsHistory) -> AnnotationSpecsHistory:
+        """
+        作業ガイド履歴に、以下のキーを追加する.
+        user_id
+        username
+
+        Args:
+            instruction_history:
+
+        Returns:
+            instruction_history
+        """
+        return self._add_user_info(instruction_history)
+
     def add_properties_to_inspection(
         self, inspection: Inspection, detail: Optional[Dict[str, Any]] = None
     ) -> Inspection:
@@ -200,7 +228,7 @@ class AddProps:
 
             commenter_account_id = inspection["commenter_account_id"]
             if commenter_account_id is not None:
-                member = self.get_organization_member_from_account_id(commenter_account_id)
+                member = self.get_project_member_from_account_id(commenter_account_id)
                 if member is not None:
                     commenter_user_id = member["user_id"]
                     commenter_username = member["username"]
@@ -220,6 +248,36 @@ class AddProps:
 
         return inspection
 
+    def add_properties_to_single_annotation(self, annotation: SingleAnnotation) -> SingleAnnotation:
+        """
+        アノテーション情報（details）検査コメントに、以下のキーを追加する.
+        detail.label_name_en
+        detail.user_id
+        detail.username
+
+        Args:
+            annotation: アノテーション
+
+        Returns:
+            情報が追加されたアノテーション
+        """
+        detail = annotation["detail"]
+        detail["label_name_en"] = self.get_label_name(detail["label_id"], MessageLocale.EN)
+
+        account_id = detail["account_id"]
+        user_id = None
+        username = None
+        if account_id is not None:
+            member = self.get_project_member_from_account_id(account_id)
+            if member is not None:
+                user_id = member["user_id"]
+                username = member["username"]
+
+        detail["user_id"] = user_id
+        detail["username"] = username
+
+        return annotation
+
     def add_properties_to_task(self, task: Task) -> Task:
         """
         タスク情報に、以下のキーを追加する.
